@@ -27,6 +27,12 @@
 #include "fmpr.h"
 #include "mag.h"
 
+#ifndef flint_abort
+#if __FLINT_RELEASE <= 20502
+#define flint_abort abort
+#endif
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -991,7 +997,7 @@ ARB_DLL extern void _arf_add_tmp_cleanup(void);
 
 int _arf_add_mpn(arf_t z, mp_srcptr xp, mp_size_t xn, int xsgnbit,
     const fmpz_t xexp, mp_srcptr yp, mp_size_t yn, int ysgnbit,
-    mp_bitcnt_t shift, slong prec, arf_rnd_t rnd);
+    flint_bitcnt_t shift, slong prec, arf_rnd_t rnd);
 
 int arf_add(arf_ptr z, arf_srcptr x, arf_srcptr y, slong prec, arf_rnd_t rnd);
 int arf_add_si(arf_ptr z, arf_srcptr x, slong y, slong prec, arf_rnd_t rnd);
@@ -1063,6 +1069,8 @@ arf_submul_fmpz(arf_ptr z, arf_srcptr x, const fmpz_t y, slong prec, arf_rnd_t r
         return arf_submul_mpz(z, x, COEFF_TO_PTR(*y), prec, rnd);
 }
 
+int arf_sosq(arf_t z, const arf_t x, const arf_t y, slong prec, arf_rnd_t rnd);
+
 int arf_div(arf_ptr z, arf_srcptr x, arf_srcptr y, slong prec, arf_rnd_t rnd);
 
 ARF_INLINE int
@@ -1212,7 +1220,7 @@ arf_mag_add_ulp(mag_t z, const mag_t x, const arf_t y, slong prec)
     if (ARF_IS_SPECIAL(y))
     {
         flint_printf("error: ulp error not defined for special value!\n");
-        abort();
+        flint_abort();
     }
     else if (MAG_IS_LAGOM(z) && MAG_IS_LAGOM(x) && ARF_IS_LAGOM(y))
     {
@@ -1234,7 +1242,7 @@ arf_mag_set_ulp(mag_t z, const arf_t y, slong prec)
     if (ARF_IS_SPECIAL(y))
     {
         flint_printf("error: ulp error not defined for special value!\n");
-        abort();
+        flint_abort();
     }
     else
     {
@@ -1279,6 +1287,14 @@ arf_allocated_bytes(const arf_t x)
     return size;
 }
 
+int arf_load_str(arf_t res, const char * data);
+
+char * arf_dump_str(const arf_t x);
+
+int arf_load_file(arf_t res, FILE *stream);
+
+int arf_dump_file(FILE* stream, const arf_t x);
+
 #ifdef __cplusplus
 }
 #endif
